<?php
/**
 * @version     1.0.0
 * @package     com_docebo
 * @copyright   Copyright (C) 2013. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Docebo Srl. <info@docebo.com> - http://www.docebo.com
 */

// No direct access
defined('_JEXEC') or die;

require_once JPATH_COMPONENT . '/controller.php';

/**
 * Faqsupport controller class.
 */
class DoceboControllerFaqsupportForm extends DoceboController {

	/**
	 * Method to check out an item for editing and redirect to the edit form.
	 *
	 * @since    1.6
	 */
	public function edit() {
		$app = JFactory::getApplication();

		// Get the previous edit id (if any) and the current edit id.
		$previousId = (int) $app->getUserState('com_docebo.edit.faqsupport.id');
		$editId     = JFactory::getApplication()->input->getInt('id', NULL, 'array');

		// Set the user id for the user to edit in the session.
		$app->setUserState('com_docebo.edit.faqsupport.id', $editId);

		// Get the model.
		$model = $this->getModel('FaqsupportForm', 'DoceboModel');

		// Check out the item
		if ($editId) {
			$model->checkout($editId);
		}

		// Check in the previous user.
		if ($previousId) {
			$model->checkin($previousId);
		}

		// Redirect to the edit screen.
		$this->setRedirect(JRoute::_('index.php?option=com_docebo&view=faqsupport&layout=edit', FALSE));
	}

	/**
	 * Method to save a user's profile data.
	 *
	 * @return    void
	 * @since    1.6
	 */
	public function save() {
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		// Initialise variables.
		$app   = JFactory::getApplication();
		$model = $this->getModel('FaqsupportForm', 'DoceboModel');

		// Get the user data.
		$data = JFactory::getApplication()->input->get('jform', array(), 'array');

		// Validate the posted data.
		$form = $model->getForm();
		if (!$form) {
			JError::raiseError(500, $model->getError());

			return FALSE;
		}

		// Validate the posted data.
		$data = $model->validate($form, $data);

		// Check for errors.
		if ($data === FALSE) {
			// Get the validation messages.
			$errors = $model->getErrors();

			// Push up to three validation messages out to the user.
			for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++) {
				if ($errors[$i] instanceof Exception) {
					$app->enqueueMessage($errors[$i]->getMessage(), 'warning');
				} else {
					$app->enqueueMessage($errors[$i], 'warning');
				}
			}

			// Save the data in the session.
			$app->setUserState('com_docebo.edit.faqsupport.data', $data);

			// Redirect back to the edit screen.
			$id = (int) $app->getUserState('com_docebo.edit.faqsupport.id');
			$this->setRedirect(JRoute::_('index.php?option=com_docebo&view=faqsupport&layout=edit&id=' . $id, FALSE));

			return FALSE;
		}

		// Attempt to save the data.
		$return = $model->save($data);

		// Check for errors.
		if ($return === FALSE) {
			// Save the data in the session.
			$app->setUserState('com_docebo.edit.faqsupport.data', $data);

			// Redirect back to the edit screen.
			$id = (int) $app->getUserState('com_docebo.edit.faqsupport.id');
			$this->setMessage(JText::sprintf('Save failed', $model->getError()), 'warning');
			$this->setRedirect(JRoute::_('index.php?option=com_docebo&view=faqsupport&layout=edit&id=' . $id, FALSE));

			return FALSE;
		}


		// Check in the profile.
		if ($return) {
			$model->checkin($return);
		}

		// Clear the profile id from the session.
		$app->setUserState('com_docebo.edit.faqsupport.id', NULL);

		// Redirect to the list screen.
		$this->setMessage(JText::_('Item saved successfully'));
		$menu = & JSite::getMenu();
		$item = $menu->getActive();
		$this->setRedirect(JRoute::_($item->link, FALSE));

		// Flush the data from the session.
		$app->setUserState('com_docebo.edit.faqsupport.data', NULL);
	}


	function cancel() {
		$menu = & JSite::getMenu();
		$item = $menu->getActive();
		$this->setRedirect(JRoute::_($item->link, FALSE));
	}

	public function remove() {
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		// Initialise variables.
		$app   = JFactory::getApplication();
		$model = $this->getModel('FaqsupportForm', 'DoceboModel');

		// Get the user data.
		$data = JFactory::getApplication()->input->get('jform', array(), 'array');

		// Validate the posted data.
		$form = $model->getForm();
		if (!$form) {
			JError::raiseError(500, $model->getError());

			return FALSE;
		}

		// Validate the posted data.
		$data = $model->validate($form, $data);

		// Check for errors.
		if ($data === FALSE) {
			// Get the validation messages.
			$errors = $model->getErrors();

			// Push up to three validation messages out to the user.
			for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++) {
				if ($errors[$i] instanceof Exception) {
					$app->enqueueMessage($errors[$i]->getMessage(), 'warning');
				} else {
					$app->enqueueMessage($errors[$i], 'warning');
				}
			}

			// Save the data in the session.
			$app->setUserState('com_docebo.edit.faqsupport.data', $data);

			// Redirect back to the edit screen.
			$id = (int) $app->getUserState('com_docebo.edit.faqsupport.id');
			$this->setRedirect(JRoute::_('index.php?option=com_docebo&view=faqsupport&layout=edit&id=' . $id, FALSE));

			return FALSE;
		}

		// Attempt to save the data.
		$return = $model->delete($data);

		// Check for errors.
		if ($return === FALSE) {
			// Save the data in the session.
			$app->setUserState('com_docebo.edit.faqsupport.data', $data);

			// Redirect back to the edit screen.
			$id = (int) $app->getUserState('com_docebo.edit.faqsupport.id');
			$this->setMessage(JText::sprintf('Delete failed', $model->getError()), 'warning');
			$this->setRedirect(JRoute::_('index.php?option=com_docebo&view=faqsupport&layout=edit&id=' . $id, FALSE));

			return FALSE;
		}


		// Check in the profile.
		if ($return) {
			$model->checkin($return);
		}

		// Clear the profile id from the session.
		$app->setUserState('com_docebo.edit.faqsupport.id', NULL);

		// Redirect to the list screen.
		$this->setMessage(JText::_('Item deleted successfully'));
		$menu = & JSite::getMenu();
		$item = $menu->getActive();
		$this->setRedirect(JRoute::_($item->link, FALSE));

		// Flush the data from the session.
		$app->setUserState('com_docebo.edit.faqsupport.data', NULL);
	}


}